@@ -1,3 +1,18 @@
+#
+# Copyright 2021 Splunk Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
 # -*- coding: utf-8 -*-
 """
 Base class for test cases. Provides test cases to verify
@@ -7,13 +22,10 @@ field extractions and CIM compatibility.
 from .fields_tests import FieldTestTemplates
 from .cim_tests import CIMTestTemplates, FieldTestHelper
 from .index_tests import IndexTimeTestTemplate
-from .requirement_tests import ReqsTestTemplates
 import pytest
 
 
-class Basic(
-    FieldTestTemplates, CIMTestTemplates, IndexTimeTestTemplate, ReqsTestTemplates
-):
+class Basic(FieldTestTemplates, CIMTestTemplates, IndexTimeTestTemplate):
     """
     Base class for test cases. Inherit this class to include the test
     cases for an Add-on. Only implement the common tests here, all the other
@@ -25,7 +37,6 @@ class Basic(
     @pytest.mark.splunk_indextime
     @pytest.mark.splunk_searchtime_cim
     @pytest.mark.splunk_searchtime_fields
-    @pytest.mark.splunk_searchtime_requirements
     def test_events_with_untokenised_values(
         self, splunk_search_util, splunk_ingest_data, splunk_setup, record_property
     ):
