@@ -1,3 +1,18 @@
+#
+# Copyright 2021 Splunk Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
 import logging
 import pytest
 
@@ -34,11 +49,12 @@ class IndexTimeTestGenerator(object):
         store_sample = sample_generator.get_samples(store_events)
         tokenized_events = store_sample.get("tokenized_events")
         if not store_sample.get("conf_name") == "psa-data-gen":
-            LOGGER.warning(
-                "Index Time tests cannot be executed using eventgen.conf, pytest-splunk-addon-data.conf is required."
+            msg = (
+                "Index time tests cannot be executed without "
+                "pytest-splunk-addon-data.conf"
             )
-            return " Index Time tests cannot be executed using eventgen.conf,\
-                 pytest-splunk-addon-data.conf is required."
+            LOGGER.warning(msg)
+            return msg
 
         if test_type == "line_breaker":
             LOGGER.info("Generating line breaker test")
